<?php

/**
 * @file
 * Contains Drupal\quote\Form\SettingsForm.
 */

namespace Drupal\quote\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

class SettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'quote.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'quote_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('quote.settings');

    $form['modes'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Select quote modes'),
    ];
    $form['modes']['quote_modes_quote_sel'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Quote selected'),
      '#default_value' => $config->get('quote_modes_quote_sel'),
    ];
    $form['modes']['quote_modes_quote_all'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Quote all'),
      '#default_value' => $config->get('quote_modes_quote_all'),
    ];
    $form['modes']['quote_modes_quote_reply_all'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Quote and reply all'),
      '#default_value' => $config->get('quote_modes_quote_reply_all'),
    ];
    $form['modes']['quote_modes_quote_reply_sel'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Quote and reply selected'),
      '#default_value' => $config->get('quote_modes_quote_reply_sel'),
      '#disabled' => TRUE,
    ];

    $options = [];
    foreach (NodeType::loadMultiple() as $type) {
      $options[$type->id()] = $type->label();
    }
    $form['where'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Allow quotes in the:'),
    ];
    $form['where']['quote_allow_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content types'),
      '#options' => $options,
      '#default_value' => $config->get('quote_allow_types'),
    ];
    $form['where']['quote_allow_comments'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Comments'),
      '#description' => $this->t('Checkbox works if node type allow quoting'),
      '#default_value' => $config->get('quote_allow_comments'),
    ];

    $form['other'] = [
      '#type' => 'fieldset',
      '#title' => t('Other settings'),
    ];
    $form['other']['quote_selector'] = [
      '#type' => 'textfield',
      '#title' => t('CSS selector to quote'),
      '#description' => t('By default it is: #comment-form textarea'),
      '#default_value' => $config->get('quote_selector'),
    ];
    $form['other']['quote_limit'] = [
      '#type' => 'number',
      '#title' => t('Quote limit'),
      '#default_value' => $config->get('quote_limit'),
      '#max' => 9999,
      '#min' => 1,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('quote.settings')
      ->set('quote_modes_quote_sel', $form_state->getValue('quote_modes_quote_sel'))
      ->set('quote_modes_quote_all', $form_state->getValue('quote_modes_quote_all'))
      ->set('quote_modes_quote_reply_all', $form_state->getValue('quote_modes_quote_reply_all'))
      ->set('quote_modes_quote_reply_sel', $form_state->getValue('quote_modes_quote_reply_sel'))
      ->set('quote_allow_comments', $form_state->getValue('quote_allow_comments'))
      ->set('quote_allow_types', $form_state->getValue('quote_allow_types'))
      ->set('quote_selector', $form_state->getValue('quote_selector'))
      ->set('quote_limit', $form_state->getValue('quote_limit'))
      ->save();

    \Drupal::service('cache.render')->invalidateAll();
  }
}
